aboutsummaryrefslogtreecommitdiffstats
path: root/src/args.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/args.c')
-rw-r--r--src/args.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/args.c b/src/args.c
index 4f341ed..7693644 100644
--- a/src/args.c
+++ b/src/args.c
@@ -29,7 +29,7 @@
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
* OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
* Send your feedback or comments to : calcurse@culot.org
* Calcurse home page : http://culot.org/calcurse
*
*/
@@ -144,7 +144,7 @@ help_arg ()
"\tby issuing a command such as: calcurse --export > calcurse.dat\n"
"\nFor more information, type '?' from within Calcurse, "
"or read the manpage.\n"
- "Mail bug reports and suggestions to <calcurse@culot.org>.\n");
+ "Mail bug reports and suggestions to <misc@calcurse.org>.\n");
(void)snprintf (htitle, BUFSIZ, _("Calcurse %s - text-based organizer\n"),
VERSION);
@@ -506,7 +506,7 @@ more_info (void)
fputs (_("\nFor more information, type '?' from within Calcurse, "
"or read the manpage.\n"), stdout);
fputs (_("Mail bug reports and suggestions to "
- "<calcurse@culot.org>.\n"), stdout);
+ "<misc@calcurse.org>.\n"), stdout);
}
/*
@@ -29,7 +29,7 @@
* OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
- * Send your feedback or comments to : calcurse@culot.org
+ * Send your feedback or comments to : misc@calcurse.org
* Calcurse home page : http://culot.org/calcurse
*